==> tensortest-0.1.tar.gz: tensortest-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'tensortest',         # How you named your package folder (MyLib)
  packages = ['tensortest'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'TYPE YOUR DESCRIPTION HERE',   # Give a short description about your library
  author = 'Thanh Nguyen',                   # Type in your name
  author_email = 'thanhnguyen.email@domain.com',      # Type in your E-Mail
  url = 'https://github.com/thanhkaist/tensortest',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/thanhkaist/tensortest/archive/v0.1.tar.gz',    
  keywords = ['test', 'pipy', 'publish', 'how to'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> tensortest-0.2.tar.gz: tensortest-0.2/setup.py <==
from distutils.core import setup
setup(
  name = 'tensortest',         # How you named your package folder (MyLib)
  packages = ['tensortest'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'How to publish py package to PyPI',   # Give a short description about your library
  long_description_content_type='text/markdown',
  author = 'Thanh Nguyen',                   # Type in your name
  author_email = 'thanhnguyen.email@domain.com',      # Type in your E-Mail
  url = 'https://github.com/thanhkaist/tensortest',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/thanhkaist/tensortest/archive/V_0.2.tar.gz',    
  keywords = ['test', 'pipy', 'publish', 'how to'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
